from dataclasses import dataclass, field
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from nerualpha.webhookEvents.IUrlPayload import IUrlPayload
from nerualpha.webhookEvents.mms.IMMSEvent import IMMSEvent


#interface
class IMMSVCardEvent(IMMSEvent):
    vcard:IUrlPayload
